@@ -44,12 +44,8 @@ pub mod email_auth_request;
 pub use self::email_auth_request::EmailAuthRequest;
 pub mod error_detail;
 pub use self::error_detail::ErrorDetail;
-pub mod event_model;
-pub use self::event_model::EventModel;
 pub mod event_source;
 pub use self::event_source::EventSource;
-pub mod event_status;
-pub use self::event_status::EventStatus;
 pub mod experiment;
 pub use self::experiment::Experiment;
 pub mod experiment_device_config;
@@ -66,12 +62,6 @@ pub mod janus_stream;
 pub use self::janus_stream::JanusStream;
 pub mod janus_stream_request;
 pub use self::janus_stream_request::JanusStreamRequest;
-pub mod janus_task;
-pub use self::janus_task::JanusTask;
-pub mod janus_task_request;
-pub use self::janus_task_request::JanusTaskRequest;
-pub mod janus_task_type;
-pub use self::janus_task_type::JanusTaskType;
 pub mod mobile_auth_request;
 pub use self::mobile_auth_request::MobileAuthRequest;
 pub mod model_artifact;
@@ -172,8 +162,6 @@ pub mod paginated_octo_print_event_list;
 pub use self::paginated_octo_print_event_list::PaginatedOctoPrintEventList;
 pub mod paginated_polymorphic_event_list;
 pub use self::paginated_polymorphic_event_list::PaginatedPolymorphicEventList;
-pub mod paginated_polymorphic_task_list;
-pub use self::paginated_polymorphic_task_list::PaginatedPolymorphicTaskList;
 pub mod paginated_print_job_event_list;
 pub use self::paginated_print_job_event_list::PaginatedPrintJobEventList;
 pub mod paginated_print_nanny_plugin_event_list;
@@ -192,8 +180,6 @@ pub mod paginated_remote_control_command_list;
 pub use self::paginated_remote_control_command_list::PaginatedRemoteControlCommandList;
 pub mod paginated_system_info_list;
 pub use self::paginated_system_info_list::PaginatedSystemInfoList;
-pub mod paginated_task_status_list;
-pub use self::paginated_task_status_list::PaginatedTaskStatusList;
 pub mod paginated_telemetry_event_polymorphic_list;
 pub use self::paginated_telemetry_event_polymorphic_list::PaginatedTelemetryEventPolymorphicList;
 pub mod partner3_d_geeks_alert;
@@ -216,8 +202,6 @@ pub mod patched_janus_stream_request;
 pub use self::patched_janus_stream_request::PatchedJanusStreamRequest;
 pub mod patched_octo_print_device_request;
 pub use self::patched_octo_print_device_request::PatchedOctoPrintDeviceRequest;
-pub mod patched_polymorphic_event_request;
-pub use self::patched_polymorphic_event_request::PatchedPolymorphicEventRequest;
 pub mod patched_print_session_request;
 pub use self::patched_print_session_request::PatchedPrintSessionRequest;
 pub mod patched_printer_controller_request;
@@ -230,18 +214,12 @@ pub mod patched_remote_control_command_request;
 pub use self::patched_remote_control_command_request::PatchedRemoteControlCommandRequest;
 pub mod patched_system_info_request;
 pub use self::patched_system_info_request::PatchedSystemInfoRequest;
-pub mod patched_test_event_request;
-pub use self::patched_test_event_request::PatchedTestEventRequest;
 pub mod patched_user_request;
 pub use self::patched_user_request::PatchedUserRequest;
 pub mod polymorphic_event;
 pub use self::polymorphic_event::PolymorphicEvent;
 pub mod polymorphic_event_request;
 pub use self::polymorphic_event_request::PolymorphicEventRequest;
-pub mod polymorphic_task;
-pub use self::polymorphic_task::PolymorphicTask;
-pub mod polymorphic_task_request;
-pub use self::polymorphic_task_request::PolymorphicTaskRequest;
 pub mod print_job_event;
 pub use self::print_job_event::PrintJobEvent;
 pub mod print_job_event_request;
@@ -288,14 +266,6 @@ pub mod system_info;
 pub use self::system_info::SystemInfo;
 pub mod system_info_request;
 pub use self::system_info_request::SystemInfoRequest;
-pub mod task;
-pub use self::task::Task;
-pub mod task_status;
-pub use self::task_status::TaskStatus;
-pub mod task_status_request;
-pub use self::task_status_request::TaskStatusRequest;
-pub mod task_status_type;
-pub use self::task_status_type::TaskStatusType;
 pub mod telemetry_event;
 pub use self::telemetry_event::TelemetryEvent;
 pub mod telemetry_event_polymorphic;
@@ -304,15 +274,15 @@ pub mod telemetry_event_polymorphic_request;
 pub use self::telemetry_event_polymorphic_request::TelemetryEventPolymorphicRequest;
 pub mod telemetry_event_request;
 pub use self::telemetry_event_request::TelemetryEventRequest;
-pub mod test_event;
-pub use self::test_event::TestEvent;
-pub mod test_event_request;
-pub use self::test_event_request::TestEventRequest;
-pub mod test_event_type;
-pub use self::test_event_type::TestEventType;
 pub mod token_response;
 pub use self::token_response::TokenResponse;
 pub mod user;
 pub use self::user::User;
 pub mod user_request;
 pub use self::user_request::UserRequest;
+pub mod web_rtc_event;
+pub use self::web_rtc_event::WebRtcEvent;
+pub mod web_rtc_event_request;
+pub use self::web_rtc_event_request::WebRtcEventRequest;
+pub mod web_rtc_event_type;
+pub use self::web_rtc_event_type::WebRtcEventType;
